@@ -53,13 +53,14 @@ void CTCPStunThread::Reset()
     
     _fListenSocketsOnEpoll = false;
     
-    memset(&_tsaListen, '\0', sizeof(_tsaListen));
+    TransportAddressSet emptyTSA = {};
+    _tsaListen = emptyTSA; 
     
     _fNeedToExit = false;
     _spAuth.ReleaseAndClear();
     _role = RolePP;
     
-    memset(&_tsa, '\0', sizeof(_tsa));
+    _tsa = emptyTSA;
     
     _maxConnections = c_MaxNumberOfConnectionsDefault;
 
